@@ -5,6 +5,7 @@ Create binaries for the CLIs.
 import logging
 import uuid
 from pathlib import Path
+import shutil
 from typing import Set
 
 import docker
@@ -13,15 +14,12 @@ from docker.types import Mount
 LOGGER = logging.getLogger(__name__)
 
 
-def make_linux_binaries(repo_root: Path) -> Set[Path]:
+def make_linux_binaries(repo_root: Path):
     """
     Create binaries for Linux in a Docker container.
 
     Args:
         repo_root: The path to the root of the repository.
-
-    Returns:
-        A set of paths to the built binaries.
     """
     client = docker.from_env()
     dist_dir = repo_root / 'dist'
@@ -36,16 +34,18 @@ def make_linux_binaries(repo_root: Path) -> Set[Path]:
 
     # We install in editable mode to overwrite any potential
     # ``_setuptools_scm_version.txt`` file.
-    cmd_in_container = [
-        'pip',
-        'install',
-        '--editable',
-        '.[packaging]',
-        '&&',
-        'python',
-        'admin/create_pyinstaller_binaries.py',
-    ]
-    command = 'bash -c "{cmd}"'.format(cmd=' '.join(cmd_in_container))
+    cmd_in_container = ' '.join(
+        [
+            'pip',
+            'install',
+            '--editable',
+            '.[packaging]',
+            '&&',
+            'python',
+            'admin/create_pyinstaller_binaries.py',
+        ],
+    )
+    command = f'bash -c "{cmd_in_container}"'
 
     container = client.containers.run(
         image='python:3.9',
@@ -61,4 +61,3 @@ def make_linux_binaries(repo_root: Path) -> Set[Path]:
 
     status_code = container.wait()['StatusCode']
     assert status_code == 0
-    return set(dist_dir.iterdir())
